@@ -7,6 +7,8 @@
 
 #include <KQuickAddons/ManagedConfigModule>
 
+#include "output_model.h"
+
 namespace KScreen
 {
 class ConfigOperation;
@@ -15,7 +17,6 @@ class ConfigOperation;
 class ConfigHandler;
 class OrientationSensor;
 class OutputIdentifier;
-class OutputModel;
 
 class KCMKScreen : public KQuickAddons::ManagedConfigModule
 {
@@ -25,6 +26,7 @@ class KCMKScreen : public KQuickAddons::ManagedConfigModule
     Q_PROPERTY(bool backendReady READ backendReady NOTIFY backendReadyChanged)
     Q_PROPERTY(bool screenNormalized READ screenNormalized NOTIFY screenNormalizedChanged)
     Q_PROPERTY(bool perOutputScaling READ perOutputScaling NOTIFY perOutputScalingChanged)
+    Q_PROPERTY(bool xwaylandClientsScaleSupported READ xwaylandClientsScaleSupported NOTIFY xwaylandClientsScaleSupportedChanged)
     Q_PROPERTY(bool primaryOutputSupported READ primaryOutputSupported NOTIFY primaryOutputSupportedChanged)
     Q_PROPERTY(bool outputReplicationSupported READ outputReplicationSupported NOTIFY outputReplicationSupportedChanged)
     Q_PROPERTY(qreal globalScale READ globalScale WRITE setGlobalScale NOTIFY globalScaleChanged)
@@ -32,6 +34,7 @@ class KCMKScreen : public KQuickAddons::ManagedConfigModule
     Q_PROPERTY(bool autoRotationSupported READ autoRotationSupported NOTIFY autoRotationSupportedChanged)
     Q_PROPERTY(bool orientationSensorAvailable READ orientationSensorAvailable NOTIFY orientationSensorAvailableChanged)
     Q_PROPERTY(bool tabletModeAvailable READ tabletModeAvailable NOTIFY tabletModeAvailableChanged)
+    Q_PROPERTY(bool xwaylandClientsScale READ xwaylandClientsScale WRITE setXwaylandClientsScale NOTIFY xwaylandClientsScaleChanged)
 
 public:
     explicit KCMKScreen(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
@@ -59,6 +62,10 @@ public:
     qreal globalScale() const;
     void setGlobalScale(qreal scale);
 
+    bool xwaylandClientsScale() const;
+    void setXwaylandClientsScale(bool scale);
+    bool xwaylandClientsScaleSupported() const;
+
     int outputRetention() const;
     void setOutputRetention(int retention);
 
@@ -69,6 +76,7 @@ public:
     Q_INVOKABLE void forceSave();
     void doSave(bool force);
     Q_INVOKABLE void revertSettings();
+    Q_INVOKABLE void requestReboot();
 
     Q_INVOKABLE void setStopUpdatesFromBackend(bool value);
     Q_INVOKABLE void updateFromBackend();
@@ -93,6 +101,8 @@ Q_SIGNALS:
     void outputConnect(bool connected);
     void settingsReverted();
     void showRevertWarning();
+    void xwaylandClientsScaleChanged();
+    void xwaylandClientsScaleSupportedChanged();
 
 private:
     void setBackendReady(bool error);
@@ -103,7 +113,6 @@ private:
     void configReady(KScreen::ConfigOperation *op);
     void continueNeedsSaveCheck(bool needs);
 
-    std::unique_ptr<OutputIdentifier> m_outputIdentifier;
     std::unique_ptr<ConfigHandler> m_configHandler;
     OrientationSensor *m_orientationSensor;
     bool m_backendReady = false;
